@@ -173,7 +173,7 @@ class Orden(BaseModel):
         for element in orden_element.getchildren():
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
-                orden_data[tag] = element.text
+                orden_data[tag] = element.text.strip()
             if tag == 'op_ins_clave':
                 orden_data['op_ins_clave_ord'] = element.text
 
