@@ -73,6 +73,7 @@ class PrioridadOrdenPago(str, Enum):
 
 
 class CategoriaOrdenPago(str, Enum):
+    ensesion = 'ENSESION'
     respuesta = 'RESPUESTA'
     cargar_odp = 'CARGAR_ODP'
     cargar_odp_respuesta = 'CARGAR_ODP_RESPUESTA'
@@ -85,6 +86,7 @@ class CategoriaOrdenPago(str, Enum):
     odps_canceladas_x_banxico = 'ODPS_CANCELADAS_X_BANXICO'
     odps_canceladas_x_banxico_respuesta = 'ODPS_CANCELADAS_X_BANXICO_RESPUESTA'
     ensesion_respuesta = 'ENSESION_RESPUESTA'
+    cambio_conexion = 'AVISOCAMBIACONEC'
 
 
 class EstadoOrdenPago(str, Enum):
@@ -144,7 +146,7 @@ class TipoDevolucionOrdenPago(str, Enum):
     account_blocked = 2
     account_canceled = 3
     wrong_account_currency = 5
-    account_number_is_not_fondea = 6
+    account_number_does_not_belong = 6
     beneficiary_e_firma_revoked = 11
     beneficiary_unrecognized_payment = 13
     missing_required_data = 14
@@ -153,7 +155,7 @@ class TipoDevolucionOrdenPago(str, Enum):
     invalid_account_type = 17
     requested_by_origin = 18
     invalid_character = 19
-    autorized_limit_exceeded = 20
+    authorized_limit_exceeded = 20
     deposit_limit_exceeded = 21
     phone_not_registered = 22
     additional_account_can_not_receive_payments = 23
